@@ -8,6 +8,10 @@ import uuid
 logger = logging.getLogger(__name__)
 
 
+class AmqpCallbackError(Exception):
+    pass
+
+
 class Publisher(object):
     def __init__(self, channel, exchange):
         self.channel = channel
@@ -42,20 +46,31 @@ class Subscriber(object):
 
 class Method(Subscriber):
     def amqp_callback(self, channel, method, header, body):
+        result_json = {}
         try:
             result = self.callback(json.loads(body), Publisher(channel, self.exchange))
-            channel.basic_publish(exchange='',
-                routing_key=header.reply_to,
-                properties=pika.BasicProperties(
-                    correlation_id=header.correlation_id,
-                    content_type='application/json',
-                    content_encoding='utf-8',
-                ),
-                body=json.dumps(result))
-            channel.basic_ack(delivery_tag=method.delivery_tag)
+            result_json.update(dict(
+                status='success',
+                data=result
+            ))
+        except AmqpCallbackError as e:
+            result_json.update(dict(
+                status='error',
+                message=e.message
+            ))
         except Exception:
             logger.exception('AMQP message callback error')
 
+        channel.basic_publish(exchange='',
+            routing_key=header.reply_to,
+            properties=pika.BasicProperties(
+                correlation_id=header.correlation_id,
+                content_type='application/json',
+                content_encoding='utf-8',
+            ),
+            body=json.dumps(result_json))
+        channel.basic_ack(delivery_tag=method.delivery_tag)
+
 
 class AmqpMethod(object):
     def __init__(self, conn_string):
